# -*- coding: utf-8 -*-
"""
Created By Murray(m18527) on 2019/9/18 14:14
"""
from sync.worker import start_table_sync

if __name__ == '__main__':
    start_table_sync()
